//	Running models for the edited chapter
//	31JAN20
//
//	- uses moving calendar windows (not waves) for turnover
//
*********************************************************************
cd "$dir"
cd ..
clear *
use "1 - compiled ZA file, v2.dta", clear

// epimpf
/*	"HOW IMPORTANT, WOULD YOU SAY, IS THE EUROPEAN PARLIAMENT IN THE LIFE OF THE
	 EUROPEAN COMMUNITY NOWADAYS?"	*/
	
global dv epimpf	
** FLIP CODING (more important = higher values)
replace $dv = -$dv

****************************************************************************************
* MODELS 1-4
*******************
global country_ww 	runSum_ww_1yrPerc 
global others_ww	runSumEPoth_ww_1yrPerc

// loop
foreach wgt in "" "[pweight=wsample]"{
	// run no weights (1st time through) -> Table 2.1
	// run weights 	  (2nd time through) -> Appendix A, Table 1

    local wEst = cond("`wgt'"=="", "", "_w")
	
	// Model 1
	oprobit $dv $country_ww										/// 	// own-country WW turnover
				c.age##c.age female ed2_1 ed2_3 ed2_4 			/// 	// individual-level controls
				voterturnout elecEP daysLastElect_norm ageEU   	///		// nat'l-level controls
				i.wave 	  										///		// time trend
				i.nation1										///		// country FEs
			if(abs($dv)<8) `wgt', robust cluster(nation1)
	estimates store m1`wEst'_1yr
	
	// Model 2
	oprobit $dv $country_ww										/// 	// own-country WW turnover
				$others_ww 										///		// other-country WW turnover
				c.age##c.age female ed2_1 ed2_3 ed2_4 			/// 	// individual-level controls
				voterturnout elecEP daysLastElect_norm ageEU   	///		// nat'l-level controls
				i.wave 	  										///		// time trend
				i.nation1										///		// country FEs
			if(abs($dv)<8) `wgt', robust cluster(nation1)
	estimates store m2`wEst'_1yr
		
	// Model 3
	oprobit $dv $country_ww										/// 	// own-country WW turnover
				c.$others_ww##c.$others_ww 						///		// other-country WW turnover
				c.age##c.age female ed2_1 ed2_3 ed2_4 			/// 	// individual-level controls
				voterturnout elecEP daysLastElect_norm ageEU   	///		// nat'l-level controls
				i.wave 	  										///		// time trend
				i.nation1										///		// country FEs
			if(abs($dv)<8) `wgt', robust cluster(nation1)
	estimates store m3`wEst'_1yr
		
	// Model 4
	oprobit $dv $country_ww										/// 	// own-country WW turnover
				c.$others_ww##c.$others_ww 						///		// other-country WW turnover
				c.age##c.age female ed2_1 ed2_3 ed2_4 			/// 	// individual-level controls
				ageEU   										///		// nat'l-level controls
				i.wave 	  										///		// time trend
				i.nation1										///		// country FEs
			if(abs($dv)<8) `wgt', robust cluster(nation1)		
	estimates store m4`wEst'_1yr		
}	

gen flagMain = e(sample)
	

****************************************************************************************
* MODEL 5
*******************	
* How about if we shift to diff DV?  Then what?
global dv epimp1	
** FLIP CODING (more important = higher values)
replace $dv = -$dv

// loop
foreach wgt in "" "[pweight=wsample]"{
    // run no weights (1st time through) -> Table 2.1
	// run weights 	  (2nd time through) -> unreported
	
	local wEst = cond("`wgt'"=="", "", "_w")
	
	// Model 5 
	// (uses (subset of) main analysis sample)
	oprobit $dv $country_ww										/// 	// own-country WW turnover
				c.$others_ww##c.$others_ww 						///		// other-country WW turnover
				c.age##c.age female ed2_1 ed2_3 ed2_4 			/// 	// individual-level controls
				voterturnout elecEP daysLastElect_norm ageEU   	///		// nat'l-level controls
				i.wave 	  										///		// time trend
				i.nation1										///		// country FEs
			if(abs($dv)<8 & flagMain==1) `wgt', robust cluster(nation1)
	estimates store mA1`wEst'_1yr	
}	

****************************************************************
// Quickly list all the EB waves that make it in, for a simple fn. cut and paste.
levelsof surv if(flagMain==1), c local(ebs)
di subinstr("`ebs'", " ", ", ", .)


cd "$dir"