// Calculating predicted quantities using margins, all main models
// 11FEB20 
//
*************************************************************
// Setting up graph directory
cd "$dir"
cap mkdir "../_graphs"
cd "../_graphs"

*************************************************************
// For all datasets
global country_ww 	runSum_ww_1yrPerc 
global others_ww	runSumEPoth_ww_1yrPerc

* remember that inrange includes start/end values => [,], not (,)
global era1 = `"inrange(survSt, date("01jan1900", "DMY"), date("31oct1993", "DMY"))"'
global era2 = `"inrange(survSt, date("01nov1993", "DMY"), date("30apr2004", "DMY"))"'
global era3 = `"inrange(survSt, date("01may2004", "DMY"), date("30apr2020", "DMY"))"'

* era labels
global era1Txt = "Pre-Maastricht"
global era1Dt  = "(08AUG79-31OCT93)"

global era2Txt = "Post-Maastricht"
global era2Dt  = "(01NOV93-30APR04)"

global era3Txt = "Post-Enlargement"
global era3Dt  = "(01MAY04-07NOV11)"

* DV labels
global y3 = "Pr(Less Important)"
global y2 = "Pr(About the Same)"
global y1 = "Pr(More Important)"

* IV labels
global x$country_ww = "Resp-country's MEP WS Dropout, Past Year (%)"
global x$others_ww  = "Other Countries' MEP WS Dropout, Past Year (%)"

* big mod list
global modList = ""

********************************************************************************
// ERAS 1 and 2
********************
clear *
use "../1 - compiled ZA file, v2.dta", clear

// DV set
global dv epimpf
	
// Housekeep
* toss DK/NA
recode $dv (8=.)
* flip coding (more important = higher values)
replace $dv = -$dv
* trim
keep $dv year accDate runSum* age female ed* voterturnout elecEP daysLastElect_norm ageEU wave nation1 survSt wsample
	
* loop over eras
forvalues e = 1/2{	// don't have anything in era3 in ZA
		
	// Unweighted model	
	oprobit $dv c.$country_ww##c.$country_ww					/// 	// own-country WW turnover
				c.$others_ww##c.$others_ww 						///		// other-country WW turnover
				c.age##c.age female ed2_1 ed2_3 ed2_4 			/// 	// individual-level controls
				voterturnout elecEP daysLastElect_norm ageEU   	///		// nat'l-level controls
				i.wave 	  										///		// time trend
				i.nation1										///		// country FEs
			if(abs($dv)<8 & ${era`e'}), robust cluster(nation1)
		estimates store era`e'_m3_2_1yr
		
		global modList = `"$modList era`e'_m3_2_1yr"'
		
	// Weighted	
	oprobit $dv c.$country_ww##c.$country_ww					/// 	// own-country WW turnover
				c.$others_ww##c.$others_ww 						///		// other-country WW turnover
				c.age##c.age female ed2_1 ed2_3 ed2_4 			/// 	// individual-level controls
				voterturnout elecEP daysLastElect_norm ageEU   	///		// nat'l-level controls
				i.wave 	  										///		// time trend
				i.nation1										///		// country FEs
			if(abs($dv)<8 & ${era`e'}) [pweight=wsample],		///
			robust cluster(nation1)
		estimates store era`e'_m3_2_1yrW

}


**********************************************
// ERAS 1 + 2: Generate pred probs, FDs (margins, OV)
*****************
// ALL GRAPH OPTIONS
* lvls
#delimit ;

global lvlOpts = `"	plotopts(c(i) msize(small) ) recastci(rspike) 
					legend(off) 
					xlabel(, form(%4.0g) labsize(*.8) alt) 
					xtitle("") ytitle("") 
					l2title("\`yTitle'", size(*.85) ) 
					l1title("\`yTitleSub'", size(*.6) margin(tiny)) 
					title("") 
					scheme(s2mono) graphregion(color(white) icolor(none) margin(small)) "';

#delimit cr

* FDs
#delimit ;

global fdOpts = `"	plotopts(c(i) msize(small) ) recastci(rspike)
					legend(off) xsc(noli) 
					xlabel(, form(%4.0g) labsize(*.75) alt) 
					ylabel(, labsize(*.85)) 
					xtitle("") ytitle("") 
					l2title("\`yTitle'", size(*.85) ) 
					l1title("\`yTitleSub'", size(*.6) margin(tiny)) 
					yline(0, lc(black) lp(solid)) 
					title("", size(*.85)) 
					scheme(s2mono) graphregion(color(white) icolor(none) margin(small))  "';

#delimit cr

*****************
// get unique DV values
qui levelsof $dv, local(dvVals)

// Start looping
* models
foreach m of global modList{
	* relevant covariates
	local xCnt = 1	// because I think the var names will make the graph names too long
	foreach x of varlist $country_ww $others_ww{
		* DV values
		foreach o of local dvVals{
		
			// 11FEB20 note: add era label in indv plot (first one in row), then add col name
			// with gr combine.  Relevant because if you bind by col, not by rows, you can ensure
			// xcommon is respected, whereas I don't think that'll be the case when you bind by rows
		
		
			// Era number
			qui di regexm("`m'", "era([0-9])")
			local e = regexs(1)
			
			// If DV val equals least imp, add y-title -> ERA LABEL
			local yTitle    = cond(`o'==-3, "${era`e'Txt}", "")
			local yTitleSub = cond(`o'==-3, "${era`e'Dt}", "")
			
		 // > Levels
			estimates restore `m' 
			sum `x' if(_est_`m'==1), detail
			
			margins, post ///
				predict(pr outcome(`o')) ///
				at((asobserved) _all `x'=(`r(p5)' `r(p25)' `r(p50)' `r(p75)' `r(p95)') )
			estimates store margE`e'Y`=abs(`o')'`xCnt'_lvls
			
			marginsplot , ///
				$lvlOpts ///
				name(margE`e'Y`=abs(`o')'`xCnt'_lvls, replace)
				
			graph save "margE`e'Y`=abs(`o')'`xCnt'_lvls.gph", replace	
			
		 // > FDs
			estimates restore `m' 
			sum `x' if(_est_`m'==1), detail
			
			margins, post ///
				predict(pr outcome(`o')) ///
				at((asobserved) _all `x'=(`r(p5)' `r(p25)' `r(p50)' `r(p75)' `r(p95)') ) ///
				contrast(atcontrast(ar) pv) 
			estimates store margE`e'Y`=abs(`o')'`xCnt'_FDs
			
			marginsplot, ///
				$fdOpts ///
				name(margE`e'Y`=abs(`o')'`xCnt'_FDs, replace)	
				
			graph save "margE`e'Y`=abs(`o')'`xCnt'_FDs.gph", replace	
	
		}

		local `xCnt++'		
	}				
}



********************************************************************************
// ERA 3 (Clark and Rohrschneider 2019)
********************
use "../3 - trimmed Clark.dta", clear

* set DV
global dv eprole	
	
* loop over eras
global modList = ""
local e = 3
{		
	// Unweighted model
	oprobit $dv c.$country_ww##c.$country_ww					/// 	// own-country WW turnover
				c.$others_ww##c.$others_ww 						///		// other-country WW turnover
				c.age##c.age female ed2_1 ed2_3 ed2_4 			/// 	// individual-level controls
				voterturnout elecEP daysLastElect_norm ageEU   	///		// nat'l-level controls
				i.wave 	  										///		// time trend
				i.clarkCC										///		// country FEs
			if(abs($dv)<8 & ${era`e'}), robust cluster(clarkCC) 	

	estimates store era`e'_m3_2_1yr
	
	global modList = `"$modList era`e'_m3_2_1yr"'
}


**********************************************
// ERA 3: Generate pred probs, FDs (margins, OV)
*****************
qui levelsof $dv, local(dvVals)

* models
foreach m of global modList{
	* relevant covariates
	local xCnt = 1	// because I think the var names will make the graph names too long
	foreach x of varlist $country_ww $others_ww{
		* DV values
		foreach o of local dvVals{
		
			// Era number
			qui di regexm("`m'", "era([0-9])")
			local e = regexs(1)
			
			// If DV val equals least imp, add y-title -> ERA LABEL
			local yTitle    = cond(`o'==-3, "${era`e'Txt}", "")
			local yTitleSub = cond(`o'==-3, "${era`e'Dt}", "")
			
		 // > Levels
			estimates restore `m' 
			sum `x' if(_est_`m'==1), detail
			
			margins, post ///
				predict(pr outcome(`o')) ///
				at((asobserved) _all `x'=(`r(p5)' `r(p25)' `r(p50)' `r(p75)' `r(p95)') )
			estimates store margE`e'Y`=abs(`o')'`xCnt'_lvls
			
			marginsplot , ///
				$lvlOpts ///
				name(margE`e'Y`=abs(`o')'`xCnt'_lvls, replace)
			
			graph save "margE`e'Y`=abs(`o')'`xCnt'_lvls.gph", replace
			
		// > FDs
			estimates restore `m' 
			sum `x' if(_est_`m'==1), detail
			
			margins, post ///
				predict(pr outcome(`o')) ///
				at((asobserved) _all `x'=(`r(p5)' `r(p25)' `r(p50)' `r(p75)' `r(p95)') ) ///
				contrast(atcontrast(ar) pv) 
			estimates store margE`e'Y`=abs(`o')'`xCnt'_FDs
			
			marginsplot, ///
				$fdOpts ///
				name(margE`e'Y`=abs(`o')'`xCnt'_FDs, replace)	
				
			graph save "margE`e'Y`=abs(`o')'`xCnt'_FDs.gph", replace	
		}
		
		local `xCnt++'

	}
				
}
****************************************************************************************************
// Do the graphs
qui levelsof $dv, local(dvVals)

// FD + lvls
foreach st in lvls FDs{
	
	// relevant covariates
	local xCnt = 1
	foreach x of varlist $country_ww $others_ww{
		
		// DV levels => COLS
		foreach o of local dvVals{

			local delt = cond("`st'"=="FDs", "{&Delta}", "")
			
			* ycommon
			graph combine 	margE1Y`=abs(`o')'`xCnt'_`st' ///
							margE2Y`=abs(`o')'`xCnt'_`st' ///
							margE3Y`=abs(`o')'`xCnt'_`st' ///  
				, ///
				cols(1) xcommon ycommon ///
				title("`delt'${y`=abs(`o')'}", size(*.85)) ///
				scheme(s2mono) graphregion(color(white) icolor(none)) name(y`=abs(`o')'`xCnt'_`st'YC, replace)
			
			graph save "col - y`=abs(`o')'`xCnt'_`st'YC.gph", replace
			
			* no ycommon
			graph combine 	margE1Y`=abs(`o')'`xCnt'_`st' ///
							margE2Y`=abs(`o')'`xCnt'_`st' ///
							margE3Y`=abs(`o')'`xCnt'_`st' ///  
				, ///
				cols(1) xcommon  ///
				title("`delt'${y`=abs(`o')'}", size(*.85)) ///
				scheme(s2mono) graphregion(color(white) icolor(none)) name(y`=abs(`o')'`xCnt'_`st', replace)
			
			graph save "col - y`=abs(`o')'`xCnt'_`st'.gph", replace
		}
		
		// Combine everything into one graph
		foreach end in "YC" ""{
			graph combine y3`xCnt'_`st'`end' y2`xCnt'_`st'`end' y1`xCnt'_`st'`end' ///
				, ///
				rows(1) ///
				b1title("${x`x'}", size(*.95)) ///
				title("") ///
				scheme(s2mono) graphregion(color(white) icolor(none) margin(small)) name(`st'`end', replace)
				
			graph save "_all - `x', `st'`end'.gph", replace	
			graph export "_all - `x', `st'`end'.png", width(2112) height(1536) replace
		}	
		local `xCnt++'	
	}
}	

cd "$dir"