//	Putting this here, because seems like we might have to call it
//	from multiple do files.  Want to ensure the code's generalizable.
//
//	10SEP18
***************************************************

// import, mini-clean
import excel "eb_countries-over-time.xlsx", sheet("Fieldwork Dates") firstrow clear
* ^ Note: replaced all . in Eurobarometer IDs with __ in original spreadsheet, for recovery after the fact.
	
	drop if(_n==1 | _n==3 | _n==4)											// toss the super text-y rows with information we don't need
	replace EurobarometerSurvey = strtrim(stritrim(EurobarometerSurvey))	// getting rid of extra spaces now
	drop HN HO																// toss blank columns
	compress
	
	
// Get things in friendly name format for reshape
rename (*) (eb_*)
	rename (eb_Euro*) (Euro*)
	rename (eb_B eb_C) (B C)
	
	
// Get in country codes from EP1 paper
* ugh, easier to do later.  Just generate fake ID for now, for the reshape.
gen id = _n

	
// If there's no exact date, pull the header at the top and fill in before tossing the rows
replace eb_ECS70 = "Feb 1970" if(regexm(eb_ECS70, "no exact date"))
replace eb_ECS71 = "Jul 1971" if(regexm(eb_ECS71, "no exact date"))
replace eb_ECS73 = "Sep 1973" if(regexm(eb_ECS73, "no exact date"))

drop in 1/2
	
	// Fix all the inconsistent coding.
	* Macedonia
	replace eb_EB67__2 = "04.2007 - 05.2007" 		if(id==26)
	
	* Finland
	replace eb_EB40 = "10.1993 - 11.1993" 			if(id==13)
	
	* Norway
	replace eb_EB34__0    = "11.1990 - 12.1990" 	if(id==31)
	replace eb_EB43__043__1 = "03.1995 - 05.1995" 	if(id==31)
	replace eb_EB43__1    = "04.1995 - 05.1995" 	if(id==31)
	
	* Luxembourg
	replace eb_EB12  = "06.10.1979 - 22.10.1979" 	if(id==25)	// seems like they flipped the day around, typing 60 instead of 06
	replace eb_EB41__0 = "29.03.1994 - 10.05.1994" 	if(id==25)
	
	* France
	replace eb_EB7 = "25.4.1977-09.05.1977" 		if(id==14)	// seems likely that this was meant to be april, not month 24

	* Slovakia
	replace eb_EB79__2 = "29.04.2013 - 12.05.2013" 	if(id==36) 	// seems like they fat-fingered a key, typing 39 instead of 29

	* Greece
	replace eb_EB44__2 = "05.12.1995 - 22.12.1995" 	if(id==18) 	// there's probably a way to get Stata to recognize this as a date by removing spaces, but easier just to do this.
	
	
// reshape	
reshape long eb_, i(id) j(surv)	s
rename eb_ survDate
rename Eurobaro country

	* toss the CC surveys, for sanity while proofing.
	drop if(regexm(surv, "^[C][C]"))

	
// Get earliest date range
split survDate, parse("-")
drop survDate2
replace survDate1 = strtrim(stritrim(survDate1))

// convert into date.
gen double survSt = date(survDate1, "DMY")
format survSt %td

	* For the waves that just have months:
	gen double temp = date(survDate1, "MY") if(survSt==.)
	format temp %td
	replace survSt = temp if(survSt==. & temp!=.)
	drop temp
	
// Get in Clark's ccodes
clarkCodes, gen(clarkCC) cname(country)
	
// Get in ZA's ccodes, since that's the merge that has to happen first before the EP1 dataset.
zaCodes, gen(nation1) cname(country)
drop if nation1==. & clarkCC==. // Turkey isn't part of the EU.	(Lithuania won't get accidentally dropped, now that the code error's fixed in the helper function.)

	
// Get in the Eurobarometer codes for the merge
replace surv = subinstr(surv, "__", ".", .)
	// for survs ending in a single capital letter, insert a period before that letter (to match with codes below)
	gen temp1 = length(surv)-1
	gen temp2 = substr(surv, 1, temp1)
	clonevar surv2 = surv
	gen flag = regexm(surv, "[0-9][A-Z]$")
	replace surv2 = temp2 + "." + regexs(0) if(regexm(surv, "[A-Z]$") & flag==1)
	drop temp1 temp2 flag
	
gen eb = .
	// NOTE: The regexm's a little dangerous, since EB47 is
	// referring to "EB47", but regexm will flag "EB47",
	// "EB47.1", and "EB47.2" as well.  The fact that you
	// code the second two *AFTER* the broader recode for EB47
	// makes everything work out, though.  Miraculously.
	
	// NO, still ended up being too dangerous.  Went with straight matches instead.

foreach var of varlist surv surv2{
	replace eb = 1 if(eb==. &`var'== "ECS70")
	replace eb = 2 if(eb==. &`var'== "ECS71")
	replace eb = 3 if(eb==. &`var'== "ECS73")
	replace eb = 20 if(eb==. &`var'== "EB2")
	replace eb = 30 if(eb==. &`var'== "EB3")
	replace eb = 40 if(eb==. &`var'== "EB4")
	replace eb = 50 if(eb==. &`var'== "EB5")
	replace eb = 60 if(eb==. &`var'== "EB6")
	replace eb = 70 if(eb==. &`var'== "EB7")
	replace eb = 80 if(eb==. &`var'== "EB8")
	replace eb = 90 if(eb==. &`var'== "EB9")
	replace eb = 100 if(eb==. &`var'== "EB10")
	replace eb = 101 if(eb==. &`var'== "EB10A")
	replace eb = 110 if(eb==. &`var'== "EB11")
	replace eb = 120 if(eb==. &`var'== "EB12")
	replace eb = 130 if(eb==. &`var'== "EB13")
	replace eb = 140 if(eb==. &`var'== "EB14")
	replace eb = 150 if(eb==. &`var'== "EB15")
	replace eb = 160 if(eb==. &`var'== "EB16")
	replace eb = 170 if(eb==. &`var'== "EB17")
	replace eb = 180 if(eb==. &`var'== "EB18")
	replace eb = 190 if(eb==. &`var'== "EB19")
	replace eb = 200 if(eb==. &`var'== "EB20")
	replace eb = 210 if(eb==. &`var'== "EB21")
	replace eb = 220 if(eb==. &`var'== "EB22")
	replace eb = 230 if(eb==. &`var'== "EB23")
	replace eb = 240 if(eb==. &`var'== "EB24")
	replace eb = 250 if(eb==. &`var'== "EB25")
	replace eb = 260 if(eb==. &`var'== "EB26")
	replace eb = 270 if(eb==. &`var'== "EB27")
	replace eb = 280 if(eb==. &`var'== "EB28")
	replace eb = 281 if(eb==. &`var'== "EB28.1")
	replace eb = 290 if(eb==. &`var'== "EB29")
	replace eb = 300 if(eb==. &`var'== "EB30")
	replace eb = 310 if(eb==. &`var'== "EB31")
	replace eb = 311 if(eb==. &`var'== "EB31.A")
	replace eb = 320 if(eb==. &`var'== "EB32.A")
	replace eb = 321 if(eb==. &`var'== "EB32.B")
	replace eb = 330 if(eb==. &`var'== "EB33")
	replace eb = 340 if(eb==. &`var'== "EB34.0")
	replace eb = 341 if(eb==. &`var'== "EB34.1")
	replace eb = 342 if(eb==. &`var'== "EB34.2")	// Clark add
	replace eb = 350 if(eb==. &`var'== "EB35.0")
	replace eb = 351 if(eb==. &`var'== "EB35.1")
	replace eb = 360 if(eb==. &`var'== "EB36")
	replace eb = 370 if(eb==. &`var'== "EB37.0")
	replace eb = 371 if(eb==. &`var'== "EB37.1")
	replace eb = 372 if(eb==. &`var'== "EB37.2")	// Clark add
	replace eb = 380 if(eb==. &`var'== "EB38.0")
	replace eb = 381 if(eb==. &`var'== "EB38.1")	// Clark add
	replace eb = 390 if(eb==. &`var'== "EB39.0")
	replace eb = 391 if(eb==. &`var'== "EB39.1")
	replace eb = 400 if(eb==. &`var'== "EB40")
	replace eb = 410 if(eb==. &`var'== "EB41.0")
	replace eb = 411 if(eb==. &`var'== "EB41.1")
	replace eb = 420 if(eb==. &`var'== "EB42")
	replace eb = 430 if(eb==. &`var'== "EB43.0")
	replace eb = 431 if(eb==. &`var'== "EB43.1")
	replace eb = 432 if(eb==. &`var'== "EB43.1bis")
	replace eb = 440 if(eb==. &`var'== "EB44.0")
	replace eb = 441 if(eb==. &`var'== "EB44.1")
	replace eb = 442 if(eb==. &`var'== "EB44.2")	// Clark add
	replace eb = 443 if(eb==. &`var'== "EB44.3")	// Clark add
	replace eb = 451 if(eb==. &`var'== "EB45.1")
	replace eb = 460 if(eb==. &`var'== "EB46.0")
	replace eb = 461 if(eb==. &`var'== "EB46.1")
	replace eb = 470 if(eb==. &`var'== "EB47")
	replace eb = 470 if(eb==. &`var'== "EB47.0")
	replace eb = 471 if(eb==. &`var'== "EB47.1")
	replace eb = 472 if(eb==. &`var'== "EB47.2")
	replace eb = 480 if(eb==. &`var'== "EB48")
	replace eb = 480 if(eb==. &`var'== "EB48.0")
	replace eb = 490 if(eb==. &`var'== "EB49")
	replace eb = 500 if(eb==. &`var'== "EB50.0")
	replace eb = 501 if(eb==. &`var'== "EB50.1")
	replace eb = 510 if(eb==. &`var'== "EB51.0")
	replace eb = 511 if(eb==. &`var'== "EB51.1")
	replace eb = 520 if(eb==. &`var'== "EB52.0")
	replace eb = 521 if(eb==. &`var'== "EB52.1")
	replace eb = 530 if(eb==. &`var'== "EB53.0")
	replace eb = 530 if(eb==. &`var'== "EB53")
	replace eb = 540 if(eb==. &`var'== "EB54.0")
	replace eb = 541 if(eb==. &`var'== "EB54.1")
	replace eb = 542 if(eb==. &`var'== "EB54.2")
	replace eb = 550 if(eb==. &`var'== "EB55.0")
	replace eb = 551 if(eb==. &`var'== "EB55.1")
	replace eb = 552 if(eb==. &`var'== "EB55.2")
	replace eb = 560 if(eb==. &`var'== "EB56.0")
	replace eb = 561 if(eb==. &`var'== "EB56.1")
	replace eb = 562 if(eb==. &`var'== "EB56.2")
	replace eb = 563 if(eb==. &`var'== "EB56.3")
	replace eb = 570 if(eb==. &`var'== "EB57.0")
	replace eb = 571 if(eb==. &`var'== "EB57.1")
	replace eb = 572 if(eb==. &`var'== "EB57.2")
	
	// All Clark adds, past this point
	replace eb = 580 if(eb==. &`var'== "EB58.0")	
	replace eb = 581 if(eb==. &`var'== "EB58.1")	
	replace eb = 582 if(eb==. &`var'== "EB58.2")	
	replace eb = 590 if(eb==. &`var'== "EB59.0")	
	replace eb = 591 if(eb==. &`var'== "EB59.1")	
	replace eb = 592 if(eb==. &`var'== "EB59.2")	
	replace eb = 600 if(eb==. &`var'== "EB60.0")
	replace eb = 601 if(eb==. &`var'== "EB60.1")
	replace eb = 602 if(eb==. &`var'== "EB60.2")
	replace eb = 603 if(eb==. &`var'== "EB60.3")
	replace eb = 610 if(eb==. &`var'== "EB61")
	replace eb = 620 if(eb==. &`var'== "EB62.0")
	replace eb = 621 if(eb==. &`var'== "EB62.1")
	replace eb = 622 if(eb==. &`var'== "EB62.2")
	replace eb = 631 if(eb==. &`var'== "EB63.1")
	replace eb = 632 if(eb==. &`var'== "EB63.2")
	replace eb = 633 if(eb==. &`var'== "EB63.3")
	replace eb = 634 if(eb==. &`var'== "EB63.4")
	replace eb = 635 if(eb==. &`var'== "EB63.5")
	replace eb = 641 if(eb==. &`var'== "EB64.1")
	replace eb = 642 if(eb==. &`var'== "EB64.2")
	replace eb = 643 if(eb==. &`var'== "EB64.3")
	replace eb = 644 if(eb==. &`var'== "EB64.4")
	replace eb = 651 if(eb==. &`var'== "EB65.1")
	replace eb = 652 if(eb==. &`var'== "EB65.2")
	replace eb = 653 if(eb==. &`var'== "EB65.3")
	replace eb = 654 if(eb==. &`var'== "EB65.4")
	replace eb = 661 if(eb==. &`var'== "EB66.1")
	replace eb = 662 if(eb==. &`var'== "EB66.2")
	replace eb = 663 if(eb==. &`var'== "EB66.3")
	replace eb = 671 if(eb==. &`var'== "EB67.1")
	replace eb = 672 if(eb==. &`var'== "EB67.2")
	replace eb = 673 if(eb==. &`var'== "EB67.3")
	replace eb = 681 if(eb==. &`var'== "EB68.1")
	replace eb = 682 if(eb==. &`var'== "EB68.2")
	replace eb = 691 if(eb==. &`var'== "EB69.1")
	replace eb = 692 if(eb==. &`var'== "EB69.2")
	replace eb = 701 if(eb==. &`var'== "EB70.1")
	replace eb = 711 if(eb==. &`var'== "EB71.1")
	replace eb = 712 if(eb==. &`var'== "EB71.2")
	replace eb = 713 if(eb==. &`var'== "EB71.3")
	replace eb = 721 if(eb==. &`var'== "EB72.1")
	replace eb = 722 if(eb==. &`var'== "EB72.2")
	replace eb = 723 if(eb==. &`var'== "EB72.3")
	replace eb = 724 if(eb==. &`var'== "EB72.4")
	replace eb = 725 if(eb==. &`var'== "EB72.5")
	replace eb = 731 if(eb==. &`var'== "EB73.1")
	replace eb = 732 if(eb==. &`var'== "EB73.2")
	replace eb = 733 if(eb==. &`var'== "EB73.3")
	replace eb = 734 if(eb==. &`var'== "EB73.4")
	replace eb = 735 if(eb==. &`var'== "EB73.5")
	replace eb = 741 if(eb==. &`var'== "EB74.1")
	replace eb = 742 if(eb==. &`var'== "EB74.2")
	replace eb = 743 if(eb==. &`var'== "EB74.3")
	replace eb = 751 if(eb==. &`var'== "EB75.1")
	replace eb = 752 if(eb==. &`var'== "EB75.2")
	replace eb = 753 if(eb==. &`var'== "EB75.3")
	replace eb = 754 if(eb==. &`var'== "EB75.4")
	replace eb = 761 if(eb==. &`var'== "EB76.1")
	replace eb = 762 if(eb==. &`var'== "EB76.2")
	replace eb = 763 if(eb==. &`var'== "EB76.3")
	replace eb = 764 if(eb==. &`var'== "EB76.4")
	replace eb = 771 if(eb==. &`var'== "EB77.1")
	replace eb = 772 if(eb==. &`var'== "EB77.2")
	replace eb = 773 if(eb==. &`var'== "EB77.3")
	replace eb = 774 if(eb==. &`var'== "EB77.4")
	replace eb = 781 if(eb==. &`var'== "EB78.1")
	replace eb = 782 if(eb==. &`var'== "EB78.2")
	replace eb = 791 if(eb==. &`var'== "EB79.1")
	replace eb = 792 if(eb==. &`var'== "EB79.2")
	replace eb = 793 if(eb==. &`var'== "EB79.3")
	replace eb = 794 if(eb==. &`var'== "EB79.4")
	replace eb = 795 if(eb==. &`var'== "EB79.5")
	replace eb = 801 if(eb==. &`var'== "EB80.1")
	replace eb = 802 if(eb==. &`var'== "EB80.2")
	replace eb = 811 if(eb==. &`var'== "EB81.1")
	replace eb = 812 if(eb==. &`var'== "EB81.2")
	replace eb = 813 if(eb==. &`var'== "EB81.3")
	replace eb = 814 if(eb==. &`var'== "EB81.4")
	replace eb = 815 if(eb==. &`var'== "EB81.5")
	replace eb = 821 if(eb==. &`var'== "EB82.1")
	replace eb = 822 if(eb==. &`var'== "EB82.2")
	replace eb = 823 if(eb==. &`var'== "EB82.3")
	replace eb = 824 if(eb==. &`var'== "EB82.4")
	replace eb = 831 if(eb==. &`var'== "EB83.1")
	replace eb = 832 if(eb==. &`var'== "EB83.2")
	replace eb = 833 if(eb==. &`var'== "EB83.3")
	replace eb = 834 if(eb==. &`var'== "EB83.4")
	replace eb = 841 if(eb==. &`var'== "EB84.1")
	replace eb = 842 if(eb==. &`var'== "EB84.2")
	replace eb = 843 if(eb==. &`var'== "EB84.3")
	replace eb = 844 if(eb==. &`var'== "EB84.4")
	replace eb = 851 if(eb==. &`var'== "EB85.1")
	replace eb = 852 if(eb==. &`var'== "EB85.2")
	replace eb = 853 if(eb==. &`var'== "EB85.3")
	replace eb = 861 if(eb==. &`var'== "EB86.1")
	replace eb = 862 if(eb==. &`var'== "EB86.2")
	replace eb = 863 if(eb==. &`var'== "EB86.3")
	replace eb = 871 if(eb==. &`var'== "EB87.1")
	replace eb = 873 if(eb==. &`var'== "EB87.3")
	replace eb = 881 if(eb==. &`var'== "EB88.1")
	replace eb = 882 if(eb==. &`var'== "EB88.2")
	replace eb = 883 if(eb==. &`var'== "EB88.3")


} // end foreach
*
//
	// Going nuts?
	tab surv if(eb==.)
		// None of these surveys are in the Mannheim dataset.  Excellent.
		
	drop if(eb==.)	// to get unique merge id
