cap prog drop epDateW
program define epDateW, rclass
	// INPUT: date in question (scalar; wrap as date("01jan1985", "DMY") if needed ), how many prv yrs back)
	// OUTPUT: 7x1 matrix detailing the percentage of the previous y yrs that were wave 1, wave 2...
{
	syntax [, date(string) YRs(integer 0)]
	
	// yrs warning (for others, not us)
	if(`yrs'>5){
		noi di as err "Currently written s.t. {bf:yrs} assumed to be < 5.  Modify and try again."
		exit
	}
	
	// Because you'll probably accidentally do this in the future, too
	cap confirm number `date'
	if(_rc==0){
		if(`date' > 50000){
			noi di as err "{bf:date} needs to be entered in ddMMMyyyy format.  Try again"
			exit
		}
	}
	
	tempname datMat res diff dateInp seats locM
	
	// Get inputted date into raw form
	if(_rc==0)	mata: `dateInp' = `date'
	else		mata: `dateInp' = date("`date'", "DMY")
	
	// Create empty matrix to return
	mata: `res' = J(7,1,0)
	
	// define wave entry dates (and define previous wave's end based on the next's start)
	mata: `datMat' = J(7,1,.)
	local cnt = 1
	forvalues d = 79(5)109{
		local yr = 1900 + `d'
		mata: `datMat'[`cnt',1] = date("`yr'0801", "YMD") 
		/*local wv`cnt' = date("`yr'0801", "YMD")
		
		noi di %td `wv`cnt''*/
		
		local `cnt++'
	}
	
	// See which wave the inputted date falls in
	mata: `locM' = 1
	mata: mm_locate(`datMat', `dateInp', `locM')
	mata: st_local("loc", strofreal(`locM'))
	
	// If wave 1, 100% in
	if(`loc'==1){
		mata: `res'[`locM',1] = 1
	}
	// If not wave 1, figure out the split (so long as yrs < 5, can only straddle two)
	else if(`loc'!=0){
		mata: `diff' = `dateInp' - `datMat'[`locM',1]
		mata: st_local("diffSt", strofreal(`diff'))
		mata: `res'[`locM',1] = min((1,`diff'/(`yrs'*365)))					// current wave
		if(min(1,`diffSt'/(`yrs'*365))!=1){
			mata: `res'[`locM'-1,1] = ((`yrs'*365)-`diff')/(`yrs'*365)	// previous wave spillover
		}
	}
		
	// Do seat percs
	tempname allEPSeats
	matrix `allEPSeats' = (434 \ 518 \ 518 \ 626 \ 626 \ 785 \ 766)
	mata: `seats' = `res'' * st_matrix("`allEPSeats'") //(434 \ 518 \ 518 \ 626 \ 626 \ 785 \ 766)	// <- seats in first 7 waves

	// Return the results
	tempname resStata seatsStata 
	mata: st_matrix("`resStata'", `res')
	mata: st_local("`seatsStata'", strofreal(`seats'))
	return matrix wvPcts = `resStata'
	return matrix epStAll = `allEPSeats'
	return scalar seats = ``seatsStata''
	
}
end
*************
cap prog drop ctrySeats
prog define ctrySeats
{
	
	// From Daniel and Metzger 2018 replic data
	// "EP Seats, by country-wave.dta"
	
	// COL ORDER: nation1 ID (ZA codes), wave, seats for that country
	
	mata: ctrySeats = ///
			   (2	,	1	,	24	\	///
				13	,	1	,	0	\	///
				5	,	1	,	81	\	///
				9	,	1	,	81	\	///
				8	,	1	,	15	\	///
				16	,	1	,	0	\	///
				1	,	1	,	81	\	///
				12	,	1	,	0	\	///
				17	,	1	,	0	\	///
				4	,	1	,	81	\	///
				6	,	1	,	6	\	///
				3	,	1	,	25	\	///
				7	,	1	,	16	\	///
				11	,	1	,	24	\	///
				18	,	1	,	0	\	///
				11	,	2	,	24	\	///
				6	,	2	,	6	\	///
				18	,	2	,	0	\	///
				4	,	2	,	81	\	///
				7	,	2	,	16	\	///
				5	,	2	,	81	\	///
				17	,	2	,	0	\	///
				16	,	2	,	0	\	///
				3	,	2	,	25	\	///
				12	,	2	,	60	\	///
				9	,	2	,	81	\	///
				2	,	2	,	24	\	///
				8	,	2	,	15	\	///
				13	,	2	,	24	\	///
				1	,	2	,	81	\	///
				5	,	3	,	81	\	///
				3	,	3	,	25	\	///
				9	,	3	,	81	\	///
				17	,	3	,	0	\	///
				11	,	3	,	24	\	///
				7	,	3	,	16	\	///
				6	,	3	,	6	\	///
				12	,	3	,	60	\	///
				8	,	3	,	15	\	///
				13	,	3	,	24	\	///
				1	,	3	,	81	\	///
				16	,	3	,	0	\	///
				2	,	3	,	24	\	///
				4	,	3	,	81	\	///
				18	,	3	,	0	\	///
				5	,	4	,	87	\	///
				18	,	4	,	21	\	///
				1	,	4	,	87	\	///
				7	,	4	,	16	\	///
				13	,	4	,	25	\	///
				16	,	4	,	16	\	///
				9	,	4	,	87	\	///
				11	,	4	,	25	\	///
				3	,	4	,	31	\	///
				12	,	4	,	64	\	///
				4	,	4	,	99	\	///
				8	,	4	,	15	\	///
				6	,	4	,	6	\	///
				2	,	4	,	25	\	///
				17	,	4	,	22	\	///
				16	,	5	,	16	\	///
				13	,	5	,	25	\	///
				9	,	5	,	87	\	///
				3	,	5	,	31	\	///
				12	,	5	,	64	\	///
				2	,	5	,	25	\	///
				7	,	5	,	16	\	///
				5	,	5	,	87	\	///
				17	,	5	,	22	\	///
				1	,	5	,	87	\	///
				11	,	5	,	25	\	///
				18	,	5	,	21	\	///
				8	,	5	,	15	\	///
				6	,	5	,	6	\	///
				4	,	5	,	99	\	///
				17	,	6	,	19	\	///
				13	,	6	,	24	\	///
				9	,	6	,	78	\	///
				5	,	6	,	78	\	///
				1	,	6	,	78	\	///
				4	,	6	,	99	)
				
			mata: seats2 =	///
			   (12	,	6	,	54	\	///
				16	,	6	,	14	\	///
				8	,	6	,	13	\	///
				11	,	6	,	24	\	///
				7	,	6	,	14	\	///
				2	,	6	,	24	\	///
				6	,	6	,	6	\	///
				18	,	6	,	18	\	///
				3	,	6	,	27	\	///
				2	,	7	,	22	\	///
				4	,	7	,	99	\	///
				7	,	7	,	13	\	///
				18	,	7	,	19	\	///
				1	,	7	,	74	\	///
				6	,	7	,	6	\	///
				8	,	7	,	12	\	///
				17	,	7	,	20	\	///
				3	,	7	,	26	\	///
				13	,	7	,	22	\	///
				11	,	7	,	22	\	///
				12	,	7	,	54	\	///
				16	,	7	,	13	\	///
				5	,	7	,	73	\	///
				9	,	7	,	73	)	
				
			mata: ctrySeats = ctrySeats \ seats2
			mata mata drop seats2

	****************************************************************************		
	// SEATS BY ISO CODE (to expedite)
	
	// COL ORDER: ISO3 numeric code, wave, seats for that country
	
	mata: ctrySeatsISO = ///
	   (233	,	1	,	0	\	///
		616	,	1	,	0	\	///
		56	,	1	,	24	\	///
		203	,	1	,	0	\	///
		620	,	1	,	0	\	///
		642	,	1	,	0	\	///
		380	,	1	,	81	\	///
		705	,	1	,	0	\	///
		703	,	1	,	0	\	///
		826	,	1	,	81	\	///
		372	,	1	,	15	\	///
		246	,	1	,	0	\	///
		348	,	1	,	0	\	///
		250	,	1	,	81	\	///
		191	,	1	,	0	\	///
		724	,	1	,	0	\	///
		196	,	1	,	0	\	///
		100	,	1	,	0	\	///
		440	,	1	,	0	\	///
		752	,	1	,	0	\	///
		276	,	1	,	81	\	///
		442	,	1	,	6	\	///
		528	,	1	,	25	\	///
		208	,	1	,	16	\	///
		470	,	1	,	0	\	///
		428	,	1	,	0	\	///
		300	,	1	,	24	\	///
		40	,	1	,	0	\	///
		300	,	2	,	24	\	///
		442	,	2	,	6	\	///
		40	,	2	,	0	\	///
		276	,	2	,	81	\	///
		705	,	2	,	0	\	///
		470	,	2	,	0	\	///
		348	,	2	,	0	\	///
		100	,	2	,	0	\	///
		208	,	2	,	16	\	///
		380	,	2	,	81	\	///
		752	,	2	,	0	\	///
		203	,	2	,	0	\	///
		196	,	2	,	0	\	///
		246	,	2	,	0	\	///
		528	,	2	,	25	\	///
		724	,	2	,	60	\	///
		826	,	2	,	81	\	///
		642	,	2	,	0	\	///
		191	,	2	,	0	\	///
		616	,	2	,	0	\	///
		440	,	2	,	0	\	///
		233	,	2	,	0	\	///
		56	,	2	,	24	\	///
		428	,	2	,	0	\	///
		372	,	2	,	15	\	///
		620	,	2	,	24	\	///
		250	,	2	,	81	\	///
		703	,	2	,	0	)
		
	mata: seats2 = ///
	   (380	,	3	,	81	\	///
		470	,	3	,	0	\	///
		528	,	3	,	25	\	///
		826	,	3	,	81	\	///
		196	,	3	,	0	\	///
		100	,	3	,	0	\	///
		191	,	3	,	0	\	///
		752	,	3	,	0	\	///
		300	,	3	,	24	\	///
		616	,	3	,	0	\	///
		208	,	3	,	16	\	///
		642	,	3	,	0	\	///
		442	,	3	,	6	\	///
		724	,	3	,	60	\	///
		372	,	3	,	15	\	///
		705	,	3	,	0	\	///
		620	,	3	,	24	\	///
		250	,	3	,	81	\	///
		440	,	3	,	0	\	///
		348	,	3	,	0	\	///
		246	,	3	,	0	\	///
		56	,	3	,	24	\	///
		203	,	3	,	0	\	///
		276	,	3	,	81	\	///
		233	,	3	,	0	\	///
		428	,	3	,	0	\	///
		703	,	3	,	0	\	///
		40	,	3	,	0	\	///
		380	,	4	,	87	\	///
		40	,	4	,	21	\	///
		348	,	4	,	0	\	///
		440	,	4	,	0	\	///
		250	,	4	,	87	\	///
		208	,	4	,	16	\	///
		620	,	4	,	25	\	///
		703	,	4	,	0	\	///
		246	,	4	,	16	\	///
		826	,	4	,	87	\	///
		300	,	4	,	25	\	///
		528	,	4	,	31	\	///
		470	,	4	,	0	\	///
		724	,	4	,	64	\	///
		196	,	4	,	0	\	///
		705	,	4	,	0	\	///
		276	,	4	,	99	\	///
		191	,	4	,	0	\	///
		428	,	4	,	0	\	///
		642	,	4	,	0	\	///
		616	,	4	,	0	\	///
		100	,	4	,	0	\	///
		372	,	4	,	15	\	///
		203	,	4	,	0	\	///
		233	,	4	,	0	\	///
		442	,	4	,	6	\	///
		56	,	4	,	25	\	///
		752	,	4	,	22	)

	mata: ctrySeatsISO = ctrySeatsISO \ seats2

	mata: seats2 = 	///
	   (233	,	5	,	0	\	///
		705	,	5	,	0	\	///
		246	,	5	,	16	\	///
		616	,	5	,	0	\	///
		348	,	5	,	0	\	///
		620	,	5	,	25	\	///
		196	,	5	,	0	\	///
		826	,	5	,	87	\	///
		100	,	5	,	0	\	///
		528	,	5	,	31	\	///
		470	,	5	,	0	\	///
		724	,	5	,	64	\	///
		440	,	5	,	0	\	///
		428	,	5	,	0	\	///
		56	,	5	,	25	\	///
		208	,	5	,	16	\	///
		203	,	5	,	0	\	///
		380	,	5	,	87	\	///
		752	,	5	,	22	\	///
		250	,	5	,	87	\	///
		191	,	5	,	0	\	///
		300	,	5	,	25	\	///
		40	,	5	,	21	\	///
		372	,	5	,	15	\	///
		642	,	5	,	0	\	///
		442	,	5	,	6	\	///
		276	,	5	,	99	\	///
		703	,	5	,	0	\	///
		752	,	6	,	19	\	///
		348	,	6	,	24	\	///
		233	,	6	,	6	\	///
		620	,	6	,	24	\	///
		826	,	6	,	78	\	///
		380	,	6	,	78	\	///
		250	,	6	,	78	\	///
		191	,	6	,	0	\	///
		196	,	6	,	6	\	///
		428	,	6	,	9	\	///
		705	,	6	,	7	\	///
		440	,	6	,	13	\	///
		276	,	6	,	99	\	///
		724	,	6	,	54	\	///
		616	,	6	,	54	\	///
		246	,	6	,	14	\	///
		470	,	6	,	5	\	///
		372	,	6	,	13	\	///
		300	,	6	,	24	\	///
		208	,	6	,	14	\	///
		642	,	6	,	35	\	///
		703	,	6	,	14	\	///
		100	,	6	,	18	\	///
		203	,	6	,	24	\	///
		56	,	6	,	24	\	///
		442	,	6	,	6	\	///
		40	,	6	,	18	\	///
		528	,	6	,	27	)
		
	mata: ctrySeatsISO = ctrySeatsISO \ seats2
		
	mata: seats2 = 	///
	   (56	,	7	,	22	\	///
		276	,	7	,	99	\	///
		616	,	7	,	51	\	///
		428	,	7	,	9	\	///
		348	,	7	,	22	\	///
		470	,	7	,	6	\	///
		208	,	7	,	13	\	///
		642	,	7	,	33	\	///
		40	,	7	,	19	\	///
		250	,	7	,	74	\	///
		442	,	7	,	6	\	///
		705	,	7	,	8	\	///
		372	,	7	,	12	\	///
		752	,	7	,	20	\	///
		528	,	7	,	26	\	///
		100	,	7	,	18	\	///
		703	,	7	,	13	\	///
		620	,	7	,	22	\	///
		300	,	7	,	22	\	///
		191	,	7	,	12	\	///
		724	,	7	,	54	\	///
		440	,	7	,	12	\	///
		246	,	7	,	13	\	///
		203	,	7	,	22	\	///
		380	,	7	,	73	\	///
		233	,	7	,	6	\	///
		826	,	7	,	73	\	///
		196	,	7	,	6	)

		mata: ctrySeatsISO = ctrySeatsISO \ seats2
		mata mata drop seats2
}
end