//	Putting this here, because seems like we might have to call it
//	from multiple do files.  Want to ensure the code's generalizable.
//
//	10SEP18
***************************************************
// qui do "sub - _convenience functions.do"	// if not run from main do-file

use "2 - mep - mstate ready.dta", clear

// Insert ZA country codes
zaCodes, gen(nation1) cname(country)
clarkCodes, gen(clarkCC) cname(country)
drop if(nation1==. & clarkCC==.) // EDIT - need to think through ramifications down the line


// Get one observation for every MEP-wave pairing
duplicates drop memberid wave, force


// Regenerate terms served (b/c didn't need variable for first paper, so didn't need to clean up.)
bysort memberid (wave): gen cnt = _n
	replace cnt = 0 if(wave==1)
	// NOTE: Wave 1 is otherwise going to show up with 523 new members, because 
	//		 it's technically true, but not very sensical with what we're trying
	//		 to have this variable capture.

	
// How many MEPs are new, this wave?
	* Country-by-country
	bysort wave country (memberid): egen runSum_bw_prev = total(cnt==1)
	label variable runSum_bw_prev "DRP_bw: Overall EP-wide # of freshmen MEPs this wave"

	* EP-wide
	bysort wave (memberid): egen runSumEP_bw_prev = total(cnt==1)
	label variable runSumEP_bw_prev "DRP_bw: Country-specific # of freshmen MEPs this wave"


// Can collapse to country-wave and do final manips from there
duplicates drop country_code wave, force
keep wave country_code country nation1 clarkCC runSum*

// Running sum of new MEPs
bysort country (wave): gen runSum_bw_prevAll = sum(runSum_bw_prev)
label variable runSum_bw_prevAll "DRP_bw: running sum of country-specific # of freshmen MEPs from ALL prev waves"

bysort country (wave): gen temp = sum(runSumEP_bw_prev) if(country_code==2)	// take someone that's been there since the beginning
bysort wave (country): egen runSumEP_bw_prevAll = max(temp)
label variable runSumEP_bw_prevAll "DRP_bw: running sum of EP-wide # of freshmen MEPs from ALL prev waves"
drop temp


// Merge in seats and get running totals now (could now chuck the later merge, if/when you get to it.)
preserve
	cd "$dir"
	use "EP Seats, by country-wave.dta", clear
	
	// Insert ZA country codes
	zaCodes, gen(nation1) cname(country)
	clarkCodes, gen(clarkCC) cname(country)
	drop if(nation1==. & clarkCC==.)	// EDIT - need to think through ramifications down the line
	
	gen double seatPerc = seatTotal/seatsEP
	label variable seatPerc "% of seats in wave, by country"

	label variable seatTotal "Country's # EP seats for wave"
	label variable seatsEP "Overall number of EP seats for wave"
	
	tempfile epSeats
	save `epSeats', replace
restore	

merge clarkCC wave using `epSeats', uniqusing sort keep(seatTotal seatsEP) nokeep
xtset country_code wave

	* PREVIOUS WAVE
	genD seats_prev = L1.seatTotal, ///
		label("SEATS: total country-specific # of seats in prev wave")
	
	genD seatsEP_prev = L1.seatsEP, ///
		label("SEATS: overall # of EP seats in prev wave")

	
	* ALL PREV WAVES
	bysort country (wave): genD seats_prevAll = sum(seats_prev), ///
		label("SEATS: total country-specific # of seats in ALL prev waves")
		
	bysort country (wave): gen temp = sum(seatsEP_prev) if(country_code==2)	// take someone that's been there since the beginning
	bysort wave (country): egen seatsEP_prevAll = max(temp)
	label variable seatsEP_prevAll "SEATS: overall # of EP seats in ALL prev waves"
	drop temp	
		

// The saves have to move to the bigger do-file, or else the tempfiles get purged when this finishes
/*		
// Save and go
tempfile btwnClark
save `btwnClark', replace

tempfile btwn
drop if(nation1==.)
save `btwn', replace
*/
