//	Using separate do-file to generate the year-long windows using rolling
//
//	13SEP18
***************************************************
// qui do "sub - _convenience functions.do"	// if not run from main do-file

// Load the dataset
use "mep mstate - 2 - collapsed, within-wave", clear
bysort country (date): gen runSum = sum(dropout)
clonevar end = date
tempfile running
save `running', replace

// Get running dropout variables

// For this gen setup, it's easiest to do the country-specific variables first for different time windows,
// then go to the EP-level stuff.  (B/c will have to collapse again to get unique time pts for ts)

	// Country-by-country departures
		// 1 YR
		xtset country date
		rolling r(sum), window(365) clear: sum dropout
		save "mep mstate - 2a - 1 yr windows.dta", replace
		compress
		rename _stat_1 runSum_ww_1yr
		label variable runSum_ww_1yr "DRP_ww: country-specific running # of dropouts within last year"	
		save "mep mstate - 2a - 1 yr windows.dta", replace
			// Would potentially be easier if you make the mep mstate stuff stay in memory and then
			// append the rolling stuff, but don't want to take the time to revamp the code.  Just
			// be sure to combine all the various window datasets at the end and delete the intermediates,
			// to keep things tidy.
			
			* get the dates in the first 365-day window, append for eventual merge purposes
			preserve
				//use `running', clear
				use "mep mstate - 2 - collapsed, within-wave", clear
				bysort country (date): gen runSum = sum(dropout)
				clonevar end = date
				bysort country (date): keep if(_n<365)
				rename runSum runSum_ww_1yr
				tempfile app1Yr
				save `app1Yr', replace
			restore
		
		append using `app1Yr', keep(country_code end runSum_ww_1yr) generate(appd1Yr) 
		compress
		save "mep mstate - 2a - 1 yr windows.dta", replace	
			
		// 2 YR
		use "mep mstate - 2 - collapsed, within-wave", clear
		xtset country date
		rolling r(sum), window(730) clear: sum dropout
		save "mep mstate - 2a - 2 yr windows.dta", replace
		compress
		rename _stat_1 runSum_ww_2yr
		label variable runSum_ww_2yr "DRP_ww: country-specific running # of dropouts within last 2 years"	
		save "mep mstate - 2a - 2 yr windows.dta", replace
			
			* get the dates in the first 365-day window, append for eventual merge purposes
			preserve
				//use `running', clear
				use "mep mstate - 2 - collapsed, within-wave", clear
				bysort country (date): gen runSum = sum(dropout)
				clonevar end = date
				bysort country (date): keep if(_n<730)
				rename runSum runSum_ww_2yr
				tempfile app2Yr
				save `app2Yr', replace
			restore
		
		append using `app2Yr', keep(country_code end runSum_ww_2yr) generate(appd2Yr) 
		compress
		save "mep mstate - 2a - 2 yr windows.dta", replace	
	
	
	// EP-wide departures
	** HK first
	use "mep mstate - 2 - collapsed, within-wave", clear
	gcollapse (sum) dropout, by(date)
	tsset date
	clonevar end = date
	sort date
	gen runSum = sum(dropout)
	tempfile epAll
	save `epAll', replace
	
		// 1 YR
		rolling r(sum), window(365) clear: sum dropout
		compress
		rename _stat_1 runSumEP_ww_1yr
		save "mep mstate - 2a - 1 yr windows (EP).dta", replace
		
			* get the dates in the first 365-day window, append for eventual merge purposes
			preserve
				use `epAll', clear
				keep if(_n<365)
				rename runSum runSumEP_ww_1yr
				tempfile app1Yr
				save `app1Yr', replace
			restore
		
		append using `app1Yr', keep(end runSumEP_ww_1yr) generate(appd1Yr) 
		compress
		save "mep mstate - 2a - 1 yr windows (EP).dta", replace	
		
		// 2 YR
		use `epAll', clear
		rolling r(sum), window(730) clear: sum dropout
		compress
		rename _stat_1 runSumEP_ww_2yr
		save "mep mstate - 2a - 2 yr windows (EP).dta", replace
		
			* get the dates in the first 730-day window, append for eventual merge purposes
			preserve
				use `epAll', clear
				keep if(_n<730)
				rename runSum runSumEP_ww_2yr
				tempfile app2Yr
				save `app2Yr', replace
			restore
		
		append using `app2Yr', keep(end runSumEP_ww_2yr) generate(appd2Yr) 
		compress
		save "mep mstate - 2a - 2 yr windows (EP).dta", replace	
	
	
// Housekeep by bringing everything together
use "mep mstate - 2a - 1 yr windows.dta", clear
merge country_code end using "mep mstate - 2a - 2 yr windows.dta", unique sort keep(runSum_ww_2yr)
tab _merge
drop _merge

merge end using "mep mstate - 2a - 1 yr windows (EP).dta", uniqusing sort keep(runSumEP_ww_1yr)
tab _merge
drop _merge

merge end using "mep mstate - 2a - 2 yr windows (EP).dta", uniqusing sort keep(runSumEP_ww_2yr)
tab _merge
drop _merge


// Save and move on
rename end date
sort country date
drop appd1Yr 
cap drop flag
clarkCodes, gen(clarkCC) cname(country_code) wtd

compress
epSave, n("mep mstate - 2a - _all, yr windows")

// Erase intermediate datasets (saved along the way JIC)
erase "mep mstate - 2a - 1 yr windows.dta"
erase "mep mstate - 2a - 2 yr windows.dta"
erase "mep mstate - 2a - 1 yr windows (EP).dta"
erase "mep mstate - 2a - 2 yr windows (EP).dta"
