//	Putting this here, because seems like we might have to call it
//	from multiple do files.  Want to ensure the code's generalizable.
//
//	10SEP18
***************************************************
// qui do "sub - _convenience functions.do"	// if not run from main do-file

// Get running dropout variables
	* get wave first
	waveGen, gen(wave) date(date)

	* NOTE: you'll still have observations in the dataset for JUN-AUG, in the years the wave ends.
	* ^^ You've now dealt with this by including them as part of the previous wave.  E.g., the
	*    summer after.  Reflected in waveGen coding.	

	// CURRENT WAVE
		// Country-by-country departures	
		bysort country wave (date): gen double runSum_ww_curr = sum(dropout) // gets running sum of how many dropped out, to date.
		label variable runSum_ww_curr "DRP_ww: country-specific running # of dropouts this wave"	
		
		// EP-wide departures
		bysort date (country): egen temp = total(dropout)
		bysort country wave (date): gen double runSumEP_ww_curr = sum(temp) // gets running sum of how many dropped out in all EP, to date.
		drop temp													 		// still need to sort by country b/c UoA is country-date, not date (or else you'd be summing (# countries)-more values than you should)
		label variable runSumEP_ww_curr "DRP_ww: EP-wide running # of all dropouts this wave"
		
	// PAST WAVES - country only (because something seems a little off about the all-EP stuff, and doing this is easier than finding the source)
	foreach p in runSum_ww_c /*runSumEP_c*/{
		local stub = subinstr("`p'", "_c", "", .)
		
		// pull last value from all waves
		cap drop temp
		cap drop temp2
		bysort wave country (date): gen double temp = `p' if(_n==_N)
		bysort wave country (date): egen double temp2 = max(temp)
		
		// LAST WAVE: do some trickeration
		cap drop inner
		bysort wave country (date): gen inner = _n	// within-wave counter, so first day of wave 1 will match with first day of wave 2 will match with...
		cap id country_code inner, gen(falsePanel)
		xtset falsePanel wave
		gen double `stub'_prev = L1.temp2
		label variable `stub'_prev "DRP_ww: final country-specific # of dropouts @ end of prev wave"	
		
		// ALL PAST WAVES: extend the trickeration.
		bysort country (wave date): gen temp3 = sum(temp)
		bysort country wave (date): egen `stub'_prevAll = min(temp3)
		label variable `stub'_prev "DRP_ww: running sum of country-specific final # of dropouts @ end of ALL prev waves"	
		
		cap drop temp temp2 temp3
	}	
	
	
	// PAST WAVES - EP only
	preserve
		* toss inter-wave periods
		drop if(wave==.)
		
		* get last obsv in every panel
		bysort country wave (date): gen tempFlag = _n==_N
		keep if(tempFlag==1)
		
		drop tempFlag
		 
		* AND, only keep someone that's been there since the beginning (BEL, say).  (You did verify that the numbers come out the same for all wave 1 countries, as they should.)
		keep if(country_code==2)
		
		foreach p in /*runSum_c*/ runSumEP_ww_c{
			local stub = subinstr("`p'", "_c", "", .)
			
			// LAST WAVE: do some trickeration
			xtset country wave
			gen double `stub'_prev = L1.`p'
			label variable `stub'_prev "DRP_ww: overall EP-wide # of dropouts @ end of prev wave"
			
			// ALL PAST WAVES: extend the trickeration.
			bysort country (wave date): gen temp3 = sum(`stub'_prev)
			bysort country wave (date): egen `stub'_prevAll = min(temp3)
			label variable `stub'_prevAll "DRP_ww: running sum of EP-wide final # of dropouts @ end of ALL prev waves"
			
			cap drop temp3
		}
		drop falsePanel inner
		
		tempfile epLvl
		save `epLvl', replace
	restore


// Merge in the past + past all EP variables
merge wave using `epLvl', uniqusing sort nokeep keep(runSumEP_ww_prev runSumEP_ww_prevAll)
tab _merge
drop _merge


// Insert country codes
zaCodes, gen(nation1) cname(country_code) wtd
clarkCodes, gen(clarkCC) cname(country_code) wtd
*merge country_code using `nat1', uniqusing sort nokeep keep(nation1 country)


// Save and move on
compress
sort country date
epSave, n("mep mstate - 2 - collapsed, within-wave")
	// Save moved to calling do-file, since the country sample might be different
	// if it's for the Clark vs. ZA data.
	
	// Moved back, because will be more efficient to just generate the data again 
	// for those additional countries, and then append it
	
	// Moved out again, so the same file could be used for the Clark new countries, too.

	// And then moved back one last time when you realized you didn't drop those countries.
